pecos.error\_models.noise\_impl
===============================

.. automodule:: pecos.error_models.noise_impl



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.error_models.noise_impl.gate_groups
   pecos.error_models.noise_impl.noise_initz_bitflip
   pecos.error_models.noise_impl.noise_initz_bitflip_leakage
   pecos.error_models.noise_impl.noise_meas_bitflip
   pecos.error_models.noise_impl.noise_meas_bitflip_leakage
   pecos.error_models.noise_impl.noise_sq_bitflip
   pecos.error_models.noise_impl.noise_sq_depolarizing
   pecos.error_models.noise_impl.noise_sq_depolarizing_leakage
   pecos.error_models.noise_impl.noise_tq_depolarizing
   pecos.error_models.noise_impl.noise_tq_depolarizing_leakage
